;; Generated package description from caps-lock.el  -*- no-byte-compile: t -*-
(define-package "caps-lock" "1.0" "Caps-lock as a minor mode" 'nil :commit "ce94899c7619e748e8a811ad8cdeb09918e7ecd8" :url "https://elpa.gnu.org/packages/caps-lock.html" :authors '(("Stefan Monnier" . "monnier@iro.umontreal.ca")) :maintainer '("Stefan Monnier" . "monnier@iro.umontreal.ca"))
